@@ -19,7 +19,7 @@ use UUID::Tiny;
 
 use vars qw($VERSION);
 
-$VERSION = '1.25';
+$VERSION = '1.26';
 
 our $DEBUG = 0;
 
@@ -991,7 +991,7 @@ use base 'Yote::ServerObj';
 
 sub fetch {  # fetch scrambled id
     my( $self, $in_sess_id ) = @_;
-    $self->get__ids([])->[$in_sess_id];
+    $self->get__ids([])->[$in_sess_id-1];
 }
 
 sub getid { #scramble id for object
@@ -1002,7 +1002,7 @@ sub getid { #scramble id for object
     }
     my $ids = $self->get__ids([]);
     push @$ids, $obj;
-    my $id = $#$ids;
+    my $id = scalar @$ids;
     $o2i->{$obj} = $id;
     $id;
 } #id
